<?php

namespace Alipay\Base\Oauth;

use Alipay\Kernel\BaseClient;
use function Alipay\Kernel\decrypt;

class Client extends BaseClient
{
    /**
     * 获取 token
     * @param string $grant_type
     * @param string $code
     * @param string $refresh_token
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     */
    public function getToken(string $grant_type, string $code, string $refresh_token = '')
    {

        $params = [
            'grant_type' => $grant_type,
            'code' => $code,
            'refresh_token' => $refresh_token
        ];
        $this->method = 'alipay.system.oauth.token';
        return $this->httpPost($params);
    }

    /**
     * 获取用户信息
     * @param string $token
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function user(string $token)
    {
        $this->app->config->set('auth_token', $token);
        $params = [];
        $this->method = 'alipay.user.info.share';
        return $this->httpPost($params);
    }

    /**
     * @param $content
     * @return mixed
     */
    public function decryptData($content)
    {
        $data = decrypt($content, $this->app->config->get('encrypt_key'));
        return @json_decode($data, 1);
    }
}
