<?php

namespace Alipay\Kernel\Traits;

use HttpBase\Contracts\Arrayable;
use HttpBase\Exceptions\InvalidArgumentException;
use HttpBase\Exceptions\InvalidConfigException;
use Alipay\Kernel\Http\Response;
use Alipay\Kernel\Support\Collection;
use Psr\Http\Message\ResponseInterface;

/**
 * Created by PhpStorm.
 * User: wuliangbo
 * Date: 2020/1/6
 * Time: 14:54
 */
trait ResponseCastable
{
    /**
     * @param \Psr\Http\Message\ResponseInterface $response
     * @param string|null $type
     * @return array|\Alipay\Kernel\Support\Collection|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     */
    protected function castResponseToType(ResponseInterface $response, $type = null)
    {
        $response = Response::buildFromPsrResponse($response,
            [
                'method' => $this->method,
                'sign_type' => $this->app->config->get('sign_type'),
                'alipay_public_key' => $this->app->config->get('alipay_public_key'),
            ]);
        $response->getBody()->rewind();
        switch ($type ?? 'array') {
            case 'collection':
                return $response->toCollection();
            case 'array':
                return $response->toArray();
            case 'object':
                return $response->toObject();
            case 'raw':
                return $response;
            default:
                if (!is_subclass_of($type, Arrayable::class)) {
                    throw new InvalidConfigException(sprintf('Config key "response_type" classname must be an instanceof %s', Arrayable::class));
                }

                return new $type($response);
        }
    }

    /**
     * @param mixed $response
     * @param string|null $type
     * @return array|\Alipay\Kernel\Support\Collection|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidArgumentException
     * @throws \HttpBase\Exceptions\InvalidConfigException
     */
    protected function detectAndCastResponseToType($response, $type = null)
    {
        switch (true) {
            case $response instanceof ResponseInterface:
                $response = Response::buildFromPsrResponse($response, [
                    'method' => $this->method,
                    'sign_type' => $this->app->config->get('sign_type'),
                    'alipay_public_key' => $this->app->config->get('alipay_public_key'),
                ]);

                break;
            case $response instanceof Arrayable:
                $response = new Response(200, [], json_encode($response->toArray()));

                break;
            case ($response instanceof Collection) || is_array($response) || is_object($response):
                $response = new Response(200, [], json_encode($response));

                break;
            case is_scalar($response):
                $response = new Response(200, [], (string)$response);

                break;
            default:
                throw new InvalidArgumentException(sprintf('Unsupported response type "%s"', gettype($response)));
        }

        return $this->castResponseToType($response, $type);
    }
}