<?php

namespace Alipay\Marketing\Pass;

use Alipay\Kernel\BaseClient;
use Alipay\Kernel\Support;

class Client extends BaseClient
{
    /**
     * 卡券模板创建接口
     * @param string $unique_id
     * @param string $tpl_content
     * @return Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     */
    public function createTemplate(string $unique_id, string $tpl_content)
    {
        $biz_content = [
            'unique_id' => $unique_id,
            'tpl_content' => $tpl_content
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.pass.template.add';
        $sysParams = $this->buildParams($params);
        $url = $this->_toUrlEncodedRequestBody($sysParams);
        return $this->httpPost($url, $params);
    }

    /**
     * 卡券模板更新接口
     * @param string $tpl_id
     * @param string $tpl_content
     * @return Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function updateTemplate(string $tpl_id, string $tpl_content)
    {
        $biz_content = [
            'tpl_id' => $tpl_id,
            'tpl_content' => $tpl_content
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.pass.template.update';
        return $this->httpPost($params);
    }

    /**
     * 卡券实例发放接口
     * @param string $tpl_id
     * @param string $tpl_params
     * @param string $recognition_type
     * @param string $recognition_info
     * @return Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function addInstance(string $tpl_id, string $tpl_params, string $recognition_type, string $recognition_info)
    {
        $biz_content = [
            'tpl_id' => $tpl_id,
            'tpl_params' => $tpl_params,
            'recognition_type' => $recognition_type,
            'recognition_info' => $recognition_info,
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.pass.instance.add';
        return $this->httpPost($params);
    }

    /**
     * 卡券实例更新接口
     * @param string $serial_number
     * @param string $channel_id
     * @param array $pub_params
     * @return Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     */
    public function updateInstance(string $serial_number, string $channel_id, array $pub_params = [])
    {
        $biz_content = array_merge([
            'serial_number' => $serial_number,
            'channel_id' => $channel_id,
        ], $pub_params);

        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.pass.instance.update';
        return $this->httpPost($params);
    }
}
