<?php

namespace Alipay\OfficialAccount\Message;

use Alipay\Kernel\BaseClient;

class Client extends BaseClient
{
    /**
     * 创建图文消息
     * @param string $title
     * @param string $cover
     * @param string $content
     * @param array $payload
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function createImageTextContent(string $title, string $cover, string $content, array $payload = [])
    {
        $biz_content = array_merge([
            'title' => $title,
            'cover' => $cover,
            'content' => $content
        ], $payload);
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.public.message.content.create';
        return $this->httpPost($params);
    }

    /**
     * 更新图文消息
     * @param string $content_id
     * @param string $title
     * @param string $cover
     * @param string $content
     * @param array $payload
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     */
    public function modifyImageTextContent(string $content_id, string $title, string $cover, string $content, array $payload = [])
    {
        $biz_content = array_merge([
            'content_id' => $content_id,
            'title' => $title,
            'cover' => $cover,
            'content' => $content
        ], $payload);
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.public.message.content.modify';
        return $this->httpPost($params);
    }

    /**
     * 群发消息(文本)
     * @param string $text
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function sendText(string $text)
    {
        $biz_content = [
            'msg_type' => 'text',
            'text' => $text
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.public.message.total.send';
        return $this->httpPost($params);
    }

    /**
     * 群发消息(图文)
     * @param string $articles
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function sendImageText(string $articles)
    {
        $biz_content = [
            'msg_type' => 'image-text',
            'articles' => $articles
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.public.message.total.send';
        return $this->httpPost($params);
    }

    /**
     * 查询已发送消息
     * @param array $message_ids
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function query(array $message_ids)
    {
        $biz_content = [
            'message_ids' => $message_ids
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.public.message.query';
        return $this->httpPost($params);
    }

    /**
     * 消息撤回
     * @param string $message_id
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     */
    public function recall(string $message_id)
    {
        $biz_content = [
            'message_id' => $message_id
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.public.life.msg.recall';
        return $this->httpPost($params);
    }
}
