<?php

namespace Alipay\OfficialAccount\Template;

use Alipay\Kernel\BaseClient;

class Client extends BaseClient
{
    /**
     * 模板消息行业设置
     * @param string $primary_industry_name
     * @param string $primary_industry_code
     * @param string $secondary_industry_code
     * @param string $secondary_industry_name
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function setIndustry(string $primary_industry_name, string $primary_industry_code, string $secondary_industry_code, string $secondary_industry_name)
    {
        $biz_content = [
            'primary_industry_name' => $primary_industry_name,
            'primary_industry_code' => $primary_industry_code,
            'secondary_industry_code' => $secondary_industry_code,
            'secondary_industry_name' => $secondary_industry_name
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.public.template.message.industry.modify';
        return $this->httpPost($params);
    }

    /**
     * 模板消息行业获取
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function getIndustry()
    {
        $params = [
            'biz_content' => null
        ];
        $this->method = 'alipay.open.public.setting.category.query';
        return $this->httpPost($params);
    }

    /**
     * 消息模板领取
     * @param string $template_id
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     */
    public function getTemplate(string $template_id)
    {
        $biz_content = [
            'template_id' => $template_id
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.public.template.message.get';
        return $this->httpPost($params);
    }
}
