<?php

namespace Alipay\OpenPlatform\Agent;

use Alipay\Kernel\BaseClient;

class Client extends BaseClient
{
    /**
     * 开启代商户签约、创建应用事务
     * @param string $account
     * @param array $contact_info
     * @param string $order_ticket
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function create(string $account, array $contact_info, string $order_ticket)
    {
        $biz_content = [
            'account' => $account,
            'contact_info' => $contact_info,
            'order_ticket' => $order_ticket,
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.agent.create';
        return $this->httpPost($params);
    }

    /**
     * 代商家创建小程序应用
     *
     * @param array $payload
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function miniCreate(array $payload)
    {
        $params = [
            'biz_content' => json_encode($payload, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.agent.mini.create';
        return $this->httpPost($params);
    }

    /**
     * 提交代商户签约、创建应用事务
     *
     * @param string $batchNo
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function confirm(string $batchNo)
    {
        $biz_content = [
            'batch_no' => $batchNo
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.agent.confirm';
        return $this->httpPost($params);
    }

    /**
     * 查询申请单状态
     *
     * @param string $batchNo
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function query(string $batchNo)
    {
        $biz_content = [
            'batch_no' => $batchNo
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.agent.confirm';
        return $this->httpPost($params);
    }

    /**
     * 取消代商户签约、创建应用事务
     *
     * @param string $batchNo
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function cancel(string $batchNo)
    {
        $biz_content = [
            'batch_no' => $batchNo
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.agent.cancel';
        return $this->httpPost($params);
    }
}