<?php

namespace Alipay\OpenPlatform;

use Alipay\Kernel\ServiceContainer;
use Alipay\OpenPlatform\Authorizer\MiniProgram\Application as miniProgram;
use Alipay\OpenPlatform\Authorizer\OfficialAccount\Application as officialAccount;

/**
 * Class Application
 * @package EasyAlipay\OpenPlatform
 * @property \Alipay\OpenPlatform\Server\Guard $server
 *
 * @method mixed handleAuthorize(string $grant_type, string $code, string $refresh_token = '')
 * @method mixed getPreAuthorizationUrl(string $redirect_uri, string $state, array $type = ['TINYAPP'])
 * @method mixed getAuthorizer(string $appAuthToken)
 */
class Application extends ServiceContainer
{
    /**
     * @var array
     */
    protected $providers = [
        Base\ServiceProvider::class,
        Server\ServiceProvider::class
    ];

    /**
     * @param string $appId
     * @param string|null $appAuthToken
     * @return miniProgram
     */
    public function miniProgram(string $appId, string $appAuthToken = null): miniProgram
    {
        $application = new miniProgram($this->getAuthorizerConfig($appId, $appAuthToken), $this->getReplaceServices());
        return $application;
    }

    /**
     * @param string $appId
     * @param string|null $appAuthToken
     * @return officialAccount
     */
    public function officialAccount(string $appId, string $appAuthToken = null): officialAccount
    {
        $application = new officialAccount($this->getAuthorizerConfig($appId, $appAuthToken), $this->getReplaceServices());
        return $application;
    }

    /**
     * @param string $appId
     * @param string|null $appAuthToken
     * @return array
     */
    protected function getAuthorizerConfig(string $appId, string $appAuthToken = null): array
    {
        return $this['config']->merge([
            'auth_app_id' => $appId,
            'app_auth_token' => $appAuthToken,
        ])->toArray();
    }

    /**
     * @return array
     */
    protected function getReplaceServices(): array
    {
        $services = [];
        foreach (['cache', 'http_client', 'log', 'logger', 'request'] as $reuse) {
            if (isset($this[$reuse])) {
                $services[$reuse] = $this[$reuse];
            }
        }
        return $services;
    }

    /**
     * Handle dynamic calls.
     * @param $method
     * @param $args
     * @return mixed
     */
    public function __call($method, $args)
    {
        return $this->base->$method(...$args);
    }
}
