<?php

namespace Alipay\OpenPlatform\Authorizer\MiniProgram\Experience;

use Alipay\Kernel\BaseClient;

class Client extends BaseClient
{
    /**
     * 生成小程序体验版
     * @param string $appVersion
     * @param string $bundleId
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     */
    public function create(string $appVersion, string $bundleId = 'com.alipay.alipaywallet')
    {
        $biz_content = [
            'app_version' => $appVersion,
            'bundle_id' => $bundleId,
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.mini.experience.create';
        return $this->httpPost($params);
    }

    /**
     * 查询小程序体验版 返回二维码
     *
     * @param string $appVersion
     * @param string $bundleId
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function query(string $appVersion, string $bundleId = 'com.alipay.alipaywallet')
    {
        $biz_content = [
            'app_version' => $appVersion,
            'bundle_id' => $bundleId,
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.mini.experience.query';
        return $this->httpPost($params);
    }

    /**
     * 取消体验版
     * @param string $appVersion
     * @param string $bundleId
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function cancel(string $appVersion, string $bundleId = 'com.alipay.alipaywallet')
    {
        $biz_content = [
            'app_version' => $appVersion,
            'bundle_id' => $bundleId,
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.mini.experience.cancel';
        return $this->httpPost($params);
    }
}