<?php

namespace Alipay\OpenPlatform\Authorizer\MiniProgram\Members;

use Alipay\Kernel\BaseClient;

class Client extends BaseClient
{
    /**
     * 添加成员
     * @param string $logonId
     * @param string $role
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function create(string $logonId, string $role = 'DEVELOPER')
    {
        $biz_content = [
            'logon_id' => $logonId,
            'role' => $role,
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.app.members.create';
        return $this->httpPost($params);
    }

    /**
     * 查询成员列表
     * @param string $role
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     */
    public function query(string $role = 'DEVELOPER')
    {
        $biz_content = [
            'role' => $role,
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.app.members.query';
        return $this->httpPost($params);
    }

    /**
     * 删除成员
     * @param string $userId
     * @param string $role
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     */
    public function delete(string $userId, string $role = 'DEVELOPER')
    {
        $biz_content = [
            'user_id' => $userId,
            'role' => $role,
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.app.members.delete';
        return $this->httpPost($params);
    }
}