<?php

namespace Alipay\OpenPlatform\Base;

use Alipay\Kernel\BaseClient;

class Client extends BaseClient
{
    /**
     * 换取 auth_token
     *
     * @param string $grant_type
     * @param string $code
     * @param string $refresh_token
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     */
    public function handleAuthorize(string $grant_type, string $code, string $refresh_token = '')
    {
        $biz_content = [
            'grant_type' => $grant_type,
            'code' => $code,
            'refresh_token' => $refresh_token,
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.auth.token.app';
        return $this->httpPost($params);
    }

    /**
     * 授权地址
     * @param string $redirectUri
     * @param string $state
     * @param array|string[] $type
     * @return string
     */
    public function getPreAuthorizationUrl(string $redirectUri, string $state, array $type = ['TINYAPP'])
    {
        $base_url = 'https://openauth.alipay.com/oauth2/appToAppBatchAuth.htm';
        $parmas = [
            'app_id' => $this->app->config->get('app_id'),
            'redirect_uri' => $redirectUri,
            'state' => $state,
            'application_type' => implode(',', $type)
        ];
        $query = http_build_query($parmas);
        return $base_url . '?' . $query;
    }

    /**
     * 查询某个应用授权AppAuthToken的授权信息
     *
     * @param $appAuthToken
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     */
    public function getAuthorizer($appAuthToken)
    {
        $biz_content = [
            'app_auth_token' => $appAuthToken
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.open.auth.token.app.query';
        return $this->httpPost($params);
    }
}