<?php

namespace Alipay\Payment\Order;

use Alipay\Kernel\BaseClient;

class Client extends BaseClient
{
    /**
     * 关闭订单
     * @param string $out_trade_no
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function close(string $out_trade_no)
    {
        $biz_content = [
            'out_trade_no' => $out_trade_no
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.trade.close';
        return $this->httpPost($params);
    }

    /**
     * 取消订单
     * @param string $out_trade_no
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function cancel(string $out_trade_no)
    {
        $biz_content = [
            'out_trade_no' => $out_trade_no
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.trade.cancel';
        return $this->httpPost($params);
    }

    /**
     * 查询订单
     * @param string $out_trade_no
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function query(string $out_trade_no)
    {
        $biz_content = [
            'out_trade_no' => $out_trade_no
        ];
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.trade.query';
        return $this->httpPost($params);
    }

    /**
     * 退款
     * @param string $out_trade_no
     * @param string $refund_amount
     * @param string $refund_reason
     * @param string $out_request_no
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function refund(string $out_trade_no, string $refund_amount, string $refund_reason = '订单退款', string $out_request_no = '')
    {
        $biz_content = [
            'out_trade_no' => $out_trade_no,
            'refund_amount' => $refund_amount,
            'refund_reason' => $refund_reason
        ];
        if ($out_request_no) {
            $biz_content['out_request_no'] = $out_request_no;
        }
        $params = [
            'biz_content' => json_encode($biz_content, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.trade.refund';
        return $this->httpPost($params);
    }
}
