<?php

namespace Alipay\Payment\Pay;

use Alipay\Kernel\BaseClient;

class Client extends BaseClient
{
    /**
     * 刷卡支付
     * @param array $payload
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function pos(array $payload)
    {
        $params = [
            'biz_content' => json_encode($payload, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.trade.pay';
        return $this->httpPost($params);
    }

    /**
     * app 支付
     * @param array $payload
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function app(array $payload)
    {
        $params = [
            'biz_content' => json_encode($payload, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.trade.app.pay';
        return $this->httpPost($params);
    }

    /**
     * 小程序支付
     * @param array $payload
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function mini(array $payload)
    {
        $params = [
            'biz_content' => json_encode($payload, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.trade.create';
        return $this->httpPost($params);
    }

    /**
     * 扫码支付
     * @param array $payload
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function scan(array $payload)
    {
        $params = [
            'biz_content' => json_encode($payload, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.trade.precreate';
        return $this->httpPost($params);
    }

    /**
     * wap 支付
     * @param array $payload
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Exception
     */
    public function wap(array $payload)
    {
        $payload['product_code'] = 'QUICK_WAP_WAY';
        $params = [
            'biz_content' => json_encode($payload, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.trade.wap.pay';
        return $this->httpPost($params);
    }

    /**
     *  web 支付
     * @param array $payload
     * @return \Alipay\Kernel\Support\Collection|array|object|\Psr\Http\Message\ResponseInterface|string
     * @throws \HttpBase\Exceptions\InvalidConfigException
     * @throws \GuzzleHttp\Exception\GuzzleException
     */
    public function web(array $payload)
    {
        $payload['product_code'] = 'FAST_INSTANT_TRADE_PAY';
        $params = [
            'biz_content' => json_encode($payload, JSON_UNESCAPED_UNICODE)
        ];
        $this->method = 'alipay.trade.page.pay';
        return $this->httpPost($params);
    }
}
